@@ -97,8 +97,8 @@ __all__ = [
 class ExecutionResult(NamedTuple):
     """The result of GraphQL execution.
 
-    - `data` is the result of a successful execution of the query.
-    - `errors` is included when any errors occurred as a non-empty list.
+    - ``data`` is the result of a successful execution of the query.
+    - ``errors`` is included when any errors occurred as a non-empty list.
     """
 
     data: Optional[Dict[str, Any]]
@@ -157,9 +157,7 @@ class ExecutionContext:
         self.middleware_manager = middleware_manager
         if is_awaitable:
             self.is_awaitable = is_awaitable
-        self._subfields_cache: Dict[
-            Tuple[GraphQLObjectType, int], Dict[str, List[FieldNode]]
-        ] = {}
+        self._subfields_cache: Dict[Tuple, Dict[str, List[FieldNode]]] = {}
 
     @classmethod
     def build(
@@ -678,7 +676,8 @@ class ExecutionContext:
         inner type on each item in the list.
 
         If the field type is a Scalar or Enum, ensures the completed value is a legal
-        value of the type by calling the `serialize` method of GraphQL type definition.
+        value of the type by calling the ``serialize`` method of GraphQL type
+        definition.
 
         If the field is an abstract type, determine the runtime type of the value and
         then complete based on that type.
@@ -948,14 +947,24 @@ class ExecutionContext:
         """Collect subfields.
 
         A cached collection of relevant subfields with regard to the return type is
-        kept in the execution context as `_subfields_cache`. This ensures the
+        kept in the execution context as ``_subfields_cache``. This ensures the
         subfields are not repeatedly calculated, which saves overhead when resolving
         lists of values.
         """
-        # Use id(field_nodes) as key, since a list cannot be hashed and
-        # (after conversion to a tuple) hashing nodes would be too slow:
-        cache_key = return_type, id(field_nodes)
-        sub_field_nodes = self._subfields_cache.get(cache_key)
+        cache = self._subfields_cache
+        # We cannot use the field_nodes themselves as key for the cache, since they
+        # are not hashable as a list. We also do not want to use the field_nodes
+        # themselves (converted to a tuple) as keys, since hashing them is slow.
+        # Therefore we use the ids of the field_nodes as keys. Note that we do not
+        # use the id of the list, since we want to hit the cache for all lists of
+        # the same nodes, not only for the same list of nodes. Also, the list id may
+        # even be reused, in which case we would get wrong results from the cache.
+        key = (
+            (return_type, id(field_nodes[0]))
+            if len(field_nodes) == 1  # optimize most frequent case
+            else tuple((return_type, *map(id, field_nodes)))
+        )
+        sub_field_nodes = cache.get(key)
         if sub_field_nodes is None:
             sub_field_nodes = {}
             visited_fragment_names: Set[str] = set()
@@ -968,7 +977,7 @@ class ExecutionContext:
                         sub_field_nodes,
                         visited_fragment_names,
                     )
-            self._subfields_cache[cache_key] = sub_field_nodes
+            cache[key] = sub_field_nodes
         return sub_field_nodes
 
 
@@ -1065,9 +1074,9 @@ def get_field_def(
     """Get field definition.
 
     This method looks up the field on the given type definition. It has special casing
-    for the two introspection fields, `__schema` and `__typename`. `__typename` is
+    for the two introspection fields, ``__schema`` and ``__typename``. ``__typename`` is
     special because it can always be queried as a field, even in situations where no
-    other fields are allowed, like on a Union. `__schema` could get automatically
+    other fields are allowed, like on a Union. ``__schema`` could get automatically
     added to the query type, but that would require mutating type definitions, which
     would cause issues.
 
@@ -1098,7 +1107,7 @@ def invalid_return_type_error(
 
 
 def get_typename(value: Any) -> Optional[str]:
-    """Get the `__typename` property of the given value."""
+    """Get the ``__typename`` property of the given value."""
     if isinstance(value, dict):
         return value.get("__typename")
     # need to de-mangle the attribute assumed to be "private" in Python
@@ -1117,11 +1126,12 @@ def default_type_resolver(
     If a resolve_type function is not given, then a default resolve behavior is used
     which attempts two strategies:
 
-    First, See if the provided value has a `__typename` field defined, if so, use that
+    First, See if the provided value has a ``__typename`` field defined, if so, use that
     value as name of the resolved type.
 
-    Otherwise, test each possible type for the abstract type by calling `is_type_of`
-    for the object being coerced, returning the first type that matches.
+    Otherwise, test each possible type for the abstract type by calling
+    :meth:`~graphql.type.GraphQLObjectType.is_type_of` for the object
+    being coerced, returning the first type that matches.
     """
     # First, look for `__typename`.
     type_name = get_typename(value)
@@ -1159,7 +1169,7 @@ def default_type_resolver(
     return None
 
 
-def default_field_resolver(source, info, **args):
+def default_field_resolver(source: Any, info: GraphQLResolveInfo, **args: Any) -> Any:
     """Default field resolver.
 
     If a resolve function is not given, then a default resolve behavior is used which
