@@ -78,8 +78,8 @@ class GraphQLSchema:
             # you want them to be included in the final schema.
             types=[human_type, droid_type])
 
-    Note: If a list of `directives` is provided to GraphQLSchema, that will be the
-    exact list of directives represented and allowed. If `directives` is not provided,
+    Note: If a list of ``directives`` is provided to GraphQLSchema, that will be the
+    exact list of directives represented and allowed. If ``directives`` is not provided,
     then a default set of the specified directives (e.g. @include and @skip) will be
     used. If you wish to provide *additional* directives to these specified directives,
     you must explicitly declare them. Example::
@@ -119,7 +119,7 @@ class GraphQLSchema:
         """Initialize GraphQL schema.
 
         If this schema was built from a source known to be valid, then it may be marked
-        with `assume_valid` to avoid an additional type system validation.
+        with ``assume_valid`` to avoid an additional type system validation.
         """
         self._validation_errors = [] if assume_valid else None
 
